@@ -2,4 +2,4 @@
 from __future__ import unicode_literals, division, absolute_import
 from flexget.utils.titles.series import SeriesParser, ID_TYPES
 from flexget.utils.titles.movie import MovieParser
-from flexget.utils.titles.parser import TitleParser, ParseWarning
+from flexget.utils.titles.parser import TitleParser
